package dom.table1;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.jdom2.output.Format;
import org.jdom2.output.XMLOutputter;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

import dom.table.MySaxErrorHandler;

public class TablePresentation {
	private final SAXBuilder builder = new SAXBuilder();

	public TablePresentation() {
		builder.setErrorHandler(new MySaxErrorHandler(System.err));
	}
	public void process(final String xmlFilename) throws JDOMException,
			IOException {

		// Create HTML <table><tr><th>Name</th><th>Birthday</th></tr></table>
		final Element table = new Element("table");
		final Element tableHeader = new Element("tr");
		table.addContent(tableHeader);
		tableHeader.addContent(new Element("th").addContent("Name"));
		tableHeader.addContent(new Element("th").addContent("Birthday"));

		// Read addressbook from XML input file
		final Document addressbook = builder.build(xmlFilename);
		// Search for <person> elements
		@SuppressWarnings("unchecked")
		final XPathExpression<Element> xpath = (XPathExpression<Element>) (Object) XPathFactory
				.instance().compile("/addressbook/person");
		final List<Element> persons = xpath.evaluate(addressbook);
		// Create a <tr> for each <person> element
		boolean setBackground = true;
		for (Element person : persons) {
			final Element tr = new Element("tr");
			if (setBackground) {
				tr.setAttribute("style", "background-color: #FFFF88;");
			} 
			setBackground = !setBackground;
			table.addContent(tr);
			tr.addContent(new Element("td").addContent(person.getChild("name").getText()));
			tr.addContent(new Element("td").addContent(person.getChild("birthday").getText()));
		}
		final Format outFormat = Format.getPrettyFormat();

		// Serialize to standard output
		final XMLOutputter printer = new XMLOutputter(outFormat);
		printer.output(table, System.out);
	}
}